summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_interpreters/test_channels.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_interpreters/test_channels.py')
-rw-r--r--Lib/test/test_interpreters/test_channels.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/test_interpreters/test_channels.py b/Lib/test/test_interpreters/test_channels.py
index 7e0b828..68cc45d 100644
--- a/Lib/test/test_interpreters/test_channels.py
+++ b/Lib/test/test_interpreters/test_channels.py
@@ -7,7 +7,7 @@ import time
from test.support import import_helper
# Raise SkipTest if subinterpreters not supported.
-_channels = import_helper.import_module('_xxinterpchannels')
+_channels = import_helper.import_module('_interpchannels')
from test.support import interpreters
from test.support.interpreters import channels
from .utils import _run_output, TestBase
@@ -22,7 +22,7 @@ class LowLevelTests(TestBase):
# encountered by the high-level module, thus they
# mostly shouldn't matter as much.
# Additional tests are found in Lib/test/test__xxinterpchannels.py.
# XXX Those should be either moved to LowLevelTests or eliminated
# in favor of high-level tests in this file.
@@ -22,7 +22,7 @@ class LowLevelTests(TestBase):
# encountered by the high-level module, thus they
# mostly shouldn't matter as much.
- # Additional tests are found in Lib/test/test__xxinterpchannels.py.
+ # Additional tests are found in Lib/test/test__interpchannels.py.
# XXX Those should be either moved to LowLevelTests or eliminated
# in favor of high-level tests in this file.